@@ -5,14 +5,14 @@ colVars <- function(x, suma = NULL, std = FALSE) {
   if ( !is.null(suma) ) {
     m <- suma
   } else {
-    m <- as.vector(colsums(x))
+    m <- colsums(x)
   }
 
-  n <- nrow(x)
-  x2 <- as.vector(colsums(x^2))
+  n <- dim(x)[1]
+  x2 <- colsums(x^2)
   s <- ( x2 - m^2/n ) / (n - 1)
 
-  if ( std == TRUE )  s <- sqrt(s)
+  if ( std )  s <- sqrt(s)
 
   s
 
