@@ -15,8 +15,10 @@ zip.mle <- function(x, tol = 1e-09) {
   fx <- m - m * exp(-l1) - l1 + prop * l1
   der <- m * exp(-l1) - 1 + prop
   l2 <- l1 - fx / der
-
+  
+  i <- 2
   while ( abs(l2 - l1 )> tol ) {
+    i <- i + 1
     l1 <- l2
     fx <- m - m * exp(-l1) - l1 + prop * l1
     der <- m * exp(-l1) - 1 + prop
@@ -26,12 +28,11 @@ zip.mle <- function(x, tol = 1e-09) {
 
   p <- 1 - m / l2
   
-  loglik <- no * log( p + (1 - p) * exp(-l2) ) + n1 * log(1 - p) + sum(dpois(x1, l2, log = TRUE) )
+  loglik <- no * log( p + (1 - p) * exp(-l2) ) + n1 * log(1 - p) + sum( dpois(x1, l2, log = TRUE) )
 
-  res <- c(l2, p, loglik)
-  names(res) <- c("lambda", "pi", "loglikelihood")
- 
-  res
+  param <- c(l2, p)
+  names(param) <- c("lambda", "pi")  
+  list(iters = i, loglik = loglik, param = param)
 
 }
 
